@@ -10,17 +10,11 @@ use Encode;
 use vars qw($VERSION @EXPORT_OK %EXPORT_TAGS $DEBUG);
 
 $DEBUG = 0;
-our $VERSION = '0.53';
+our $VERSION = '0.55';
 
 use base qw(Class::Accessor);
 XML::Sig->mk_accessors(qw(key));
 
-# We are exporting functions
-use base qw/Exporter/;
-
-# Export list - to allow fine tuning of export table
-@EXPORT_OK = qw( sign verify );
-
 
 use Digest::SHA qw(sha1 sha224 sha256 sha384 sha512 hmac_sha1 hmac_sha256 hmac_sha384 hmac_sha512);
 use Crypt::Digest::RIPEMD160 qw/ripemd160/;
@@ -1659,7 +1653,7 @@ XML::Sig - XML::Sig - A toolkit to help sign and verify XML Digital Signatures
 
 =head1 VERSION
 
-version 0.53
+version 0.55
 
 =head1 SYNOPSIS
 
